@@ -2,7 +2,7 @@ import json
 import logging
 import requests
 from urllib.parse import urlparse, urlunparse
-
+from raga import spinner
 logger = logging.getLogger(__name__)
 
 class HTTPClient:
@@ -72,7 +72,8 @@ class HTTPClient:
         json_data = response.json()
 
         if status_code in (200, 201) and json_data.get("success"):
-            print(json_data.get("message"))
+            spinner.succeed(json_data.get("message"))
+            spinner.start()
             logger.debug(json_data.get("message"))
             return json_data
         else:
@@ -114,7 +115,8 @@ class HTTPClient:
         json_data = response.json()
 
         if status_code in (200, 201) and json_data.get("success"):
-            print(json_data.get("message"))
+            spinner.succeed(json_data.get("message"))
+            spinner.start()
             logger.debug(json_data.get("message"))
             return json_data
         else:
